==> jc-1.4.0.tar.gz: javax/swing/ToolTipManager__24outsideTimerAction.h <==
// public class javax.swing.ToolTipManager$outsideTimerAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cc048cdc0917548a javax_swing_ToolTipManager__24outsideTimerAction

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_ToolTipManager__24outsideTimerAction_H_
#define _JC_javax_swing_ToolTipManager__24outsideTimerAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_ToolTipManager$object;

// Typedefs
typedef struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_refs	_jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_refs;
typedef struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_nonrefs	_jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_nonrefs;
typedef struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$refs	_jc_javax_swing_ToolTipManager__24outsideTimerAction$refs;
typedef struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$nonrefs	_jc_javax_swing_ToolTipManager__24outsideTimerAction$nonrefs;
typedef struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$object	_jc_javax_swing_ToolTipManager__24outsideTimerAction$object;

typedef const struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$vmethods	_jc_javax_swing_ToolTipManager__24outsideTimerAction$vmethods;
typedef const struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$vtable	_jc_javax_swing_ToolTipManager__24outsideTimerAction$vtable;
typedef const struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$vtype	_jc_javax_swing_ToolTipManager__24outsideTimerAction$vtype;

// Constructors
extern void _jc_javax_swing_ToolTipManager__24outsideTimerAction$method$_init$4f7171db22e499d9(_jc_env *, struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$object *, struct _jc_javax_swing_ToolTipManager$object *);

// Virtual methods
extern void _jc_javax_swing_ToolTipManager__24outsideTimerAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_ToolTipManager__24outsideTimerAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ToolTipManager__24outsideTimerAction$vmethods	javax_swing_ToolTipManager__24outsideTimerAction;
};

// Vtype
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$vtype {
	_jc_type			type;
	_jc_javax_swing_ToolTipManager__24outsideTimerAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_refs {
	struct _jc_javax_swing_ToolTipManager$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$refs {
    _jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_refs	javax_swing_ToolTipManager__24outsideTimerAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_nonrefs	javax_swing_ToolTipManager__24outsideTimerAction;
};

// Object instance structure
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$object {
	_jc_javax_swing_ToolTipManager__24outsideTimerAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ToolTipManager__24outsideTimerAction$vtype	*vtype;
	_jc_javax_swing_ToolTipManager__24outsideTimerAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ToolTipManager__24outsideTimerAction$vtype _jc_javax_swing_ToolTipManager__24outsideTimerAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ToolTipManager__24outsideTimerAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ToolTipManager__24outsideTimerAction$class_object;

#endif	/* _JC_javax_swing_ToolTipManager__24outsideTimerAction_H_ */

==> jc-1.4.6.tar.gz: javax/swing/ToolTipManager__24outsideTimerAction.h <==
// public class javax.swing.ToolTipManager$outsideTimerAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cc048cdc0917548a javax_swing_ToolTipManager__24outsideTimerAction

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_ToolTipManager__24outsideTimerAction_H_
#define _JC_javax_swing_ToolTipManager__24outsideTimerAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_ToolTipManager$object;

// Typedefs
typedef struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_refs	_jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_refs;
typedef struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_nonrefs	_jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_nonrefs;
typedef struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$refs	_jc_javax_swing_ToolTipManager__24outsideTimerAction$refs;
typedef struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$nonrefs	_jc_javax_swing_ToolTipManager__24outsideTimerAction$nonrefs;
typedef struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$object	_jc_javax_swing_ToolTipManager__24outsideTimerAction$object;

typedef const struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$vmethods	_jc_javax_swing_ToolTipManager__24outsideTimerAction$vmethods;
typedef const struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$vtable	_jc_javax_swing_ToolTipManager__24outsideTimerAction$vtable;
typedef const struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$vtype	_jc_javax_swing_ToolTipManager__24outsideTimerAction$vtype;

// Constructors
extern void _jc_javax_swing_ToolTipManager__24outsideTimerAction$method$_init$4f7171db22e499d9(_jc_env *, struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$object *, struct _jc_javax_swing_ToolTipManager$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_ToolTipManager__24outsideTimerAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_ToolTipManager__24outsideTimerAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_ToolTipManager__24outsideTimerAction$vmethods	javax_swing_ToolTipManager__24outsideTimerAction;
};

// Vtype
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$vtype {
	_jc_type			type;
	_jc_javax_swing_ToolTipManager__24outsideTimerAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_refs {
	struct _jc_javax_swing_ToolTipManager$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$refs {
    _jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_refs	javax_swing_ToolTipManager__24outsideTimerAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_ToolTipManager__24outsideTimerAction$sub_nonrefs	javax_swing_ToolTipManager__24outsideTimerAction;
};

// Object instance structure
struct _jc_javax_swing_ToolTipManager__24outsideTimerAction$object {
	_jc_javax_swing_ToolTipManager__24outsideTimerAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_ToolTipManager__24outsideTimerAction$vtype	*vtype;
	_jc_javax_swing_ToolTipManager__24outsideTimerAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_ToolTipManager__24outsideTimerAction$vtype _jc_javax_swing_ToolTipManager__24outsideTimerAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_ToolTipManager__24outsideTimerAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_ToolTipManager__24outsideTimerAction$class_object;

#endif	/* _JC_javax_swing_ToolTipManager__24outsideTimerAction_H_ */
